@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: addrbook.c,v 1.11 1998/10/15 20:33:05 roessler Exp $";
+static const char rcsid[]="$Id: addrbook.c,v 1.12 1998/11/10 22:14:00 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -93,7 +93,7 @@ static int alias_SortAlias (const void *a, const void *b)
 {
   ALIAS *pa = *(ALIAS **) a;
   ALIAS *pb = *(ALIAS **) b;
-  int r = strcasecmp (pa->name, pb->name);
+  int r = mutt_strcasecmp (pa->name, pb->name);
 
   return (RSORT (r));
 }
@@ -107,14 +107,14 @@ static int alias_SortAddress (const void *a, const void *b)
   if (pa->personal)
   { 
     if (pb->personal)
-      r = strcasecmp (pa->personal, pb->personal);
+      r = mutt_strcasecmp (pa->personal, pb->personal);
     else
       r = 1;
   }
   else if (pb->personal)
     r = -1;
   else
-    r = strcasecmp (pa->mailbox, pb->mailbox);
+    r = mutt_strcasecmp (pa->mailbox, pb->mailbox);
   return (RSORT (r));
 }
 
