@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: alias.c,v 1.7 1998/11/10 22:14:01 roessler Exp $";
+static const char rcsid[]="$Id: alias.c,v 1.8 1998/11/23 10:13:31 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -410,12 +410,3 @@ int mutt_addr_is_user (ADDRESS *addr)
   
   return 0;
 }
-
-/* returns 1 if the list of address contains a known mailing list */
-int mutt_is_list_recipient (ADDRESS *a)
-{
-  for (; a; a = a->next)
-    if (mutt_is_mail_list (a))
-      return 1;
-  return 0;
-}
