@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: from.c,v 1.5 1998/11/09 19:28:42 roessler Exp $";
+static const char rcsid[]="$Id: from.c,v 1.6 1998/11/10 22:14:17 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -35,7 +35,7 @@ int mutt_check_month (const char *s)
   int i;
 
   for (i = 0; i < 12; i++)
-    if (strncasecmp (s, Months[i], 3) == 0)
+    if (mutt_strncasecmp (s, Months[i], 3) == 0)
       return (i);
   return (-1); /* error */
 }
@@ -44,10 +44,10 @@ static int is_day_name (const char *s)
 {
   int i;
 
-  if ((strlen(s) < 3) || !*(s + 3) || !ISSPACE (*(s+3)))
+  if ((mutt_strlen(s) < 3) || !*(s + 3) || !ISSPACE (*(s+3)))
     return 0;
   for (i=0; i<7; i++)
-    if (strncasecmp (s, Weekdays[i], 3) == 0)
+    if (mutt_strncasecmp (s, Weekdays[i], 3) == 0)
       return 1;
   return 0;
 }
@@ -66,7 +66,7 @@ time_t is_from (const char *s, char *path, size_t pathlen)
   if (path)
     *path = 0;
 
-  if (strncmp ("From ", s, 5) != 0)
+  if (mutt_strncmp ("From ", s, 5) != 0)
     return 0;
 
   s = next_word (s); /* skip over the From part. */
