@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: help.c,v 1.11 1998/11/14 08:22:03 roessler Exp $";
+static const char rcsid[]="$Id: help.c,v 1.12 1998/12/08 23:09:53 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -174,8 +174,8 @@ static void format_line (FILE *f, int ismacro,
   }
   else
   {
-    col_a = 12 + (COLS > 83 ? (COLS - 80) >> 2 : 0);
-    col_b = 19 + (COLS > 43 ? (COLS - 16) >> 2 : 0);
+    col_a = COLS > 83 ? (COLS - 32) >> 2 : 12;
+    col_b = COLS > 49 ? (COLS - 10) >> 1 : 19;
     col = pad (f, mutt_strlen(t1), col_a);
   }
 
