@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: lib.c,v 1.20 1998/11/18 22:56:58 roessler Exp $";
+static const char rcsid[]="$Id: lib.c,v 1.21 1998/11/23 21:10:11 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -281,7 +281,7 @@ void *safe_calloc (size_t nmemb, size_t size)
   return p;
 }
 
-void *safe_malloc (unsigned int siz)
+void *safe_malloc (size_t siz)
 {
   void *p;
 
