@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: mh.c,v 1.17 1998/11/23 10:08:10 roessler Exp $";
+static const char rcsid[]="$Id: mh.c,v 1.20 1998/12/08 10:21:44 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -268,11 +268,13 @@ static int maildir_parse_dir(CONTEXT *ctx, struct maildir ***last,
 
   while ((de = readdir (dirp)) != NULL)
   {
+    
     if ((ctx->magic == M_MH && !mh_valid_message(de->d_name)) || (ctx->magic == M_MAILDIR && *de->d_name == '.'))
       continue;
     
     /* FOO - really ignore the return value? */
-    
+
+    dprint(2, (debugfile, "%s:%d: parsing %s\n", __FILE__, __LINE__, de->d_name));
     maildir_parse_entry(ctx, last, subdir, de->d_name, count, is_old);
   }
 
@@ -286,8 +288,19 @@ static void maildir_add_to_context(CONTEXT *ctx, struct maildir *md)
 {
   while(md)
   {
+    
+    dprint(2, (debugfile, "%s:%d maildir_add_to_context(): Considering %s\n",
+	       __FILE__, __LINE__, md->canon_fname));
+    
     if(md->h)
     {
+
+      dprint(2, (debugfile, "%s:%d Adding header structure. Flags: %s%s%s%s%s\n", __FILE__, __LINE__,
+		 md->h->flagged ? "f" : "",
+		 md->h->deleted ? "D" : "",
+		 md->h->replied ? "r" : "",
+		 md->h->old     ? "O" : "",
+		 md->h->read    ? "R" : ""));
       if(ctx->msgcount == ctx->hdrmax)
 	mx_alloc_memory(ctx);
       
@@ -457,7 +470,7 @@ static int maildir_sync_message (CONTEXT *ctx, int msgno)
   char oldpath[_POSIX_PATH_MAX];
   char *p;
 
-  if ((p = strchr (h->path, '/')) == NULL)
+  if ((p = strrchr (h->path, '/')) == NULL)
   {
     dprint (1, (debugfile, "maildir_sync_message: %s: unable to find subdir!\n",
 		h->path));
@@ -590,28 +603,33 @@ static char *maildir_canon_filename(char *dest, char *src, size_t l)
 {
   char *t, *u;
   
-  if((t = strchr(src, '/')))
+  if((t = strrchr(src, '/')))
     src = t + 1;
 
   strfcpy(dest, src, l);
-  if((u = strchr(dest, ';')))
+  if((u = strrchr(dest, ':')))
     *u = '\0';
-  
+
   return dest;
 }
 
 
-/* This function handles arrival of new mail and reopening of mh/maildir folders.
- * Things are getting rather complex because we don't have a
- * well-defined "mailbox order", so the tricks from mbox.c and mx.c
- * won't work here.
+/* 
+ * This function handles arrival of new mail and reopening of
+ * mh/maildir folders. Things are getting rather complex because we
+ * don't have a well-defined "mailbox order", so the tricks from
+ * mbox.c and mx.c won't work here.
+ *
+ * Don't change this code unless you _really_ understand what
+ * happens.
+ *
  */
 
 int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
 {
   char buf[_POSIX_PATH_MAX], b1[LONG_STRING], b2[LONG_STRING];
   struct stat st, st_cur;
-  short modified = 0, have_new = 0;
+  short modified = 0, have_new = 0, occult = 0;
   struct maildir *md, *p;
   struct maildir **last;
   HASH *fnames;
@@ -668,7 +686,7 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
 
   md = NULL;
   last = &md;
-  
+
   if(ctx->magic == M_MAILDIR)
   {
     if(have_new)
@@ -707,45 +725,99 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
     else
       strfcpy(b1, ctx->hdrs[i]->path, sizeof(b1));
 
-    if((p = hash_find(fnames, b1)) && p->h && 
+    dprint(2, (debugfile, "%s:%d: mh_check_mailbox(): Looking for %s.\n", __FILE__, __LINE__, b1));
+    
+    if((p = hash_find(fnames, b1)) && p->h &&
        mbox_strict_cmp_headers(ctx->hdrs[i], p->h))
     {
       /* found the right message */
-      
+
+      dprint(2, (debugfile, "%s:%d: Found.  Flags before: %s%s%s%s%s\n", __FILE__, __LINE__,
+		 ctx->hdrs[i]->flagged ? "f" : "",
+		 ctx->hdrs[i]->deleted ? "D" : "",
+		 ctx->hdrs[i]->replied ? "r" : "",
+		 ctx->hdrs[i]->old     ? "O" : "",
+		 ctx->hdrs[i]->read    ? "R" : ""));
+
+      if(mutt_strcmp(ctx->hdrs[i]->path, p->h->path))
+      {
+	safe_free((void **) &ctx->hdrs[i]->path);
+	ctx->hdrs[i]->path = safe_strdup(p->h->path);
+      }
+
       if(modified)
       {
 	if(!ctx->hdrs[i]->changed)
 	{
-	  ctx->hdrs[i]->flagged = p->h->flagged;
-	  ctx->hdrs[i]->replied = p->h->replied;
-	  ctx->hdrs[i]->old     = p->h->old;
-	  ctx->hdrs[i]->read    = p->h->read;
+	  mutt_set_flag (ctx, ctx->hdrs[i], M_FLAG, p->h->flagged);
+	  mutt_set_flag (ctx, ctx->hdrs[i], M_REPLIED, p->h->replied);
+	  mutt_set_flag (ctx, ctx->hdrs[i], M_READ, p->h->read);
 	}
+
+	mutt_set_flag(ctx, ctx->hdrs[i], M_OLD, p->h->old);
       }
-      
+
       ctx->hdrs[i]->active = 1;
+
+      dprint(2, (debugfile, "%s:%d:         Flags after: %s%s%s%s%s\n", __FILE__, __LINE__,
+		 ctx->hdrs[i]->flagged ? "f" : "",
+		 ctx->hdrs[i]->deleted ? "D" : "",
+		 ctx->hdrs[i]->replied ? "r" : "",
+		 ctx->hdrs[i]->old     ? "O" : "",
+		 ctx->hdrs[i]->read    ? "R" : ""));
+
       mutt_free_header(&p->h);
     }
-    else
+    else if (ctx->magic == M_MAILDIR && !modified && !strncmp("cur/", ctx->hdrs[i]->path, 4))
     {
-      /* the message has disappeared by occult forces, correct
-       * the index hint. 
+      /* If the cur/ part wasn't externally modified for a maildir
+       * type folder, assume the message is still active. Actually,
+       * we simply don't know.
        */
-      if(modified && index_hint && (i < *index_hint))
+
+      ctx->hdrs[i]->active = 1;
+    }
+    else if (modified || (ctx->magic == M_MAILDIR && !strncmp("new/", ctx->hdrs[i]->path, 4)))
+    {
+      
+      /* Mailbox was modified, or a new message vanished. */
+
+      /* Note: This code will _not_ apply for a new message which
+       * is just moved to cur/, as this would modify cur's time
+       * stamp and lead to modified == 1.  Thus, we'd have parsed
+       * the complete folder above, and the message would have
+       * been found in the look-up table.
+       */
+      
+      dprint(2, (debugfile, "%s:%d: Not found.  Flags were: %s%s%s%s%s\n", __FILE__, __LINE__,
+		 ctx->hdrs[i]->flagged ? "f" : "",
+		 ctx->hdrs[i]->deleted ? "D" : "",
+		 ctx->hdrs[i]->replied ? "r" : "",
+		 ctx->hdrs[i]->old     ? "O" : "",
+		 ctx->hdrs[i]->read    ? "R" : ""));
+      
+      occult = 1;
+
+      if(index_hint && (i < *index_hint))
 	deleted++;
     }
 
-    if(modified && index_hint && i == *index_hint)
+    if(index_hint && (i == *index_hint))
       *index_hint -= deleted;
   }
 
+  /* dump the file name hash */
+
   hash_destroy(&fnames, NULL);
-    
-  if(modified)
+
+  /* If we didn't just get new mail, update the tables. */
+  
+  if(modified || occult)
     mx_update_tables(ctx, 0);
 
-  maildir_move_to_context(ctx, &md);
-  
-  return modified ? M_REOPENED : have_new ? M_NEW_MAIL : 0;
-}
+  /* Incorporate new messages */
 
+  maildir_move_to_context(ctx, &md);
+
+  return (modified || occult) ? M_REOPENED : have_new ? M_NEW_MAIL : 0;
+}
