@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: pgppubring.c,v 1.9 1998/10/15 20:33:54 roessler Exp $";
+static const char rcsid[]="$Id: pgppubring.c,v 1.10 1998/11/10 22:14:44 roessler Exp $";
 /*
  * Copyright (C) 1997 Thomas Roessler <roessler@guug.de>
  * 
@@ -110,7 +110,7 @@ const char *pgp_pkalg_to_mic(const char *alg)
   
   for(i = 0; pktomic[i].pkalg; i++)
   {
-    if(!strcasecmp(pktomic[i].pkalg, alg))
+    if(!mutt_strcasecmp(pktomic[i].pkalg, alg))
       break;
   }
   
