@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: rfc2047.c,v 1.10 1998/12/02 10:11:58 roessler Exp $";
+static const char rcsid[]="$Id: rfc2047.c,v 1.11 1998/12/07 10:05:07 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -35,9 +35,20 @@ static void q_encode_string (char *d, size_t dlen, const unsigned char *s)
   char charset[SHORT_STRING];
   size_t cslen, wordlen;
   char *wptr = d;
+  const unsigned char *t;
+  int hibit = 0;
+
+  for(t = s; *t && !hibit; t++)
+    if(*t & 0x80) hibit = 1;
+
+  if(hibit)
+  {
+    snprintf (charset, sizeof (charset), "=?%s?Q?",
+	      mutt_strcasecmp ("us-ascii", Charset) == 0 ? "unknown-8bit" : NONULL(Charset));
+  }
+  else
+    strfcpy(charset, "=?us-ascii?Q?", sizeof(charset));
 
-  snprintf (charset, sizeof (charset), "=?%s?Q?",
-	    mutt_strcasecmp ("us-ascii", Charset) == 0 ? "unknown-8bit" : NONULL(Charset));
   cslen = mutt_strlen (charset);
 
   strcpy (wptr, charset);
